@@ -19,8 +19,8 @@ CREATE TABLE aux (
 INSERT INTO aux VALUES ('aux1', 'temp', -1, 0, 0, 0);
 INSERT INTO aux VALUES ('aux2', 'humidity', -1, 0, 0, 0);
 INSERT INTO aux VALUES ('aux3', 'light', -1, 0, 0, 0);
-INSERT INTO aux VALUES ('aux4', 'water1', -1, 0, 0, 0);
-INSERT INTO aux VALUES ('aux5', 'water2', -1, 0, 0, 0);
+INSERT INTO aux VALUES ('aux4', '', -1, 0, 0, 0);
+INSERT INTO aux VALUES ('aux5', '', -1, 0, 0, 0);
 INSERT INTO aux VALUES ('aux6', '', -1, 0, 0, 0);
 INSERT INTO aux VALUES ('aux7', '', -1, 0, 0, 0);
 INSERT INTO aux VALUES ('aux8', '', -1, 0, 0, 0);
@@ -40,8 +40,6 @@ INSERT INTO control VALUES ('humidity_aux_on_time', 1800);
 INSERT INTO control VALUES ('temp_aux', 'aux1');
 INSERT INTO control VALUES ('humidity_aux', 'aux2');
 INSERT INTO control VALUES ('light_aux', 'aux3');
-INSERT INTO control VALUES ('water1_aux', 'aux4');
-INSERT INTO control VALUES ('water2_aux', 'aux5');
 
 DROP TABLE IF EXISTS core;
 
@@ -60,15 +58,6 @@ INSERT INTO core VALUES ('debug_sensor', 0);
 INSERT INTO core VALUES ('log_file', "");
 INSERT INTO core VALUES ('log_level', -1);
 
-DROP TABLE IF EXISTS water;
-
-CREATE TABLE water (
-    id VARCHAR(20),
-    value VARCHAR(50)
-);
-
-INSERT INTO water VALUES ('enable', 0);
-
 DROP TABLE IF EXISTS light;
 
 CREATE TABLE light (
@@ -78,7 +67,8 @@ CREATE TABLE light (
 
 INSERT INTO light VALUES ('on_at', '18:00');
 INSERT INTO light VALUES ('on_hours', '12');
-INSERT INTO light VALUES ('on_since', 0);
+INSERT INTO light VALUES ('on_time', 0);
+INSERT INTO light VALUES ('off_time', 0);
 INSERT INTO light VALUES ('toggle', 'disabled');
 INSERT INTO light VALUES ('enable', 0);
 
